@@ -6,8 +6,13 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+from .authenticationmethodreference import AuthenticationMethodReference
+from .authorizationrequestdto import AuthorizationRequestDTO
 from .fingerprintbrowser import FingerprintBrowser
+from .oauthclientdto import OAuthClientDTO
 from .sessionassertion import SessionAssertion
+from .sessionclaims import SessionClaims
+from .sessiondto import SessionDTO
 from .sessionexists import SessionExists
 from .sessionrequired import SessionRequired
 from .subjectauthenticated import SubjectAuthenticated
@@ -17,8 +22,13 @@ from .tokenconsumed import TokenConsumed
 
 
 __all__: list[str] = [
+    'AuthenticationMethodReference',
+    'AuthorizationRequestDTO',
     'FingerprintBrowser',
+    'OAuthClientDTO',
     'SessionAssertion',
+    'SessionClaims',
+    'SessionDTO',
     'SessionExists',
     'SessionRequired',
     'SubjectAuthenticated',
