@@ -12,5 +12,6 @@ from .subject import Subject
 
 __all__: list[str] = [
     'SessionRepository',
-    'Subject'
+    'Subject',
+    'TokenRepository',
 ]
\ No newline at end of file
