@@ -8,9 +8,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 from .session import SessionRepository
 from .subject import SubjectRepository
+from .token import TokenRepository
 
 
 __all__: list[str] = [
     'SessionRepository',
     'SubjectRepository',
+    'TokenRepository',
 ]
\ No newline at end of file
