@@ -7,8 +7,10 @@
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 from .subject import *
+from .token import DatastoreTokenRepository
 
 
 __all__: list[str] = [
-    'DatastoreSubjectRepository'
+    'DatastoreSubjectRepository',
+    'DatastoreTokenRepository',
 ]
\ No newline at end of file
