@@ -7,14 +7,20 @@
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 from .apiresource import APIResource
+from .localsubjectrepository import LocalSubjectRepository
 from .principal import AuthenticatedSessionPrincipal
+from .serviceresource import ServiceResource
 from .sessionendpoint import SessionEndpoint
 from .sessionresource import SessionResource
+from .subjectresource import SubjectResource
 
 
 __all__: list[str] = [
     'AuthenticatedSessionPrincipal',
     'APIResource',
+    'LocalSubjectRepository',
+    'ServiceResource',
     'SessionEndpoint',
     'SessionResource',
+    'SubjectResource',
 ]
\ No newline at end of file
